@@ -26,6 +26,7 @@ use std::sync::{
     Arc,
 };
 use structopt::StructOpt;
+use tracing::*;
 
 use crate::{
     handle::{JointNamesAndPositions, RobotOrigin, RobotStateHandle},
@@ -242,7 +243,7 @@ impl UrdfViewerApp {
         let joint_positions = self.robot.joint_positions();
         self.robot
             .set_joint_positions(&joint_positions)
-            .unwrap_or_else(|err| println!("failed to update robot joints {}", err));
+            .unwrap_or_else(|err| error!("failed to update robot joints {}", err));
         self.viewer.update(&self.robot);
         self.update_ik_target_marker();
     }
@@ -296,7 +297,7 @@ impl UrdfViewerApp {
             if let Some(index) = self.names.iter().position(|ref n| *n == name) {
                 angles[index] = *angle;
             } else {
-                println!("{} not found, but continues", name);
+                warn!("{} not found, but continues", name);
             }
         }
         self.robot.set_joint_positions(&angles)
@@ -330,7 +331,12 @@ impl UrdfViewerApp {
             );
         }
     }
-    fn handle_key_press(&mut self, window: &mut Window, code: Key) {
+    fn handle_key_press(&mut self, window: &mut Window, code: Key, modifiers: Modifiers) {
+        let is_ctrl = modifiers.contains(NATIVE_MOD);
+        if is_ctrl {
+            // Heuristic for avoiding conflicts with browser keyboard shortcuts.
+            return;
+        }
         match code {
             Key::O | Key::LBracket => self.increment_move_joint_index(true),
             Key::P | Key::RBracket => self.increment_move_joint_index(false),
@@ -413,26 +419,20 @@ impl UrdfViewerApp {
         };
     }
     pub fn run(mut self) {
-        let window = self.window.take().unwrap();
-        let is_ctrl = false;
-        let is_shift = false;
-        let last_cur_pos_y = 0f64;
-        let last_cur_pos_x = 0f64;
-        let solver = k::JacobianIkSolver::default();
-
         #[cfg(not(target_arch = "wasm32"))]
         ctrlc::set_handler(|| {
             ABORTED.store(true, Relaxed);
         })
         .unwrap();
 
+        let window = self.window.take().unwrap();
         let state = AppState {
             app: self,
-            solver,
-            is_ctrl,
-            is_shift,
-            last_cur_pos_x,
-            last_cur_pos_y,
+            solver: k::JacobianIkSolver::default(),
+            is_ctrl: false,
+            is_shift: false,
+            last_cur_pos_x: 0.0,
+            last_cur_pos_y: 0.0,
         };
         window.render_loop(state);
     }
@@ -483,7 +483,7 @@ impl AppState {
                     self.app.update_robot();
                 }
                 Err(err) => {
-                    println!("{}", err);
+                    error!("{}", err);
                 }
             }
         }
@@ -579,12 +579,12 @@ impl window::State for AppState {
         for mut event in window.events().iter() {
             self.app.reload_and_update(window);
             match event.value {
-                WindowEvent::MouseButton(_, Action::Press, mods) => {
-                    if mods.contains(NATIVE_MOD) {
+                WindowEvent::MouseButton(_, Action::Press, modifiers) => {
+                    if modifiers.contains(NATIVE_MOD) {
                         self.is_ctrl = true;
                         event.inhibited = true;
                     }
-                    if mods.contains(Modifiers::Shift) {
+                    if modifiers.contains(Modifiers::Shift) {
                         self.is_shift = true;
                         event.inhibited = true;
                     }
@@ -630,7 +630,7 @@ impl window::State for AppState {
                                 )
                                 .unwrap_or_else(|err| {
                                     self.app.robot.set_joint_positions_unchecked(&orig_angles);
-                                    println!("Err: {}", err);
+                                    error!("{}", err);
                                 });
                             self.app.update_robot();
                         }
@@ -647,8 +647,8 @@ impl window::State for AppState {
                         event.inhibited = true;
                     }
                 }
-                WindowEvent::Key(code, Action::Press, _modifiers) => {
-                    self.app.handle_key_press(window, code);
+                WindowEvent::Key(code, Action::Press, modifiers) => {
+                    self.app.handle_key_press(window, code, modifiers);
                     event.inhibited = true;
                 }
                 _ => {}
@@ -672,6 +672,7 @@ impl window::State for AppState {
 /// Option for visualizing urdf
 #[derive(StructOpt, Debug, Deserialize)]
 #[serde(rename_all = "kebab-case")]
+#[non_exhaustive]
 pub struct Opt {
     /// Input urdf or xacro
     #[serde(default, rename = "urdf")]
@@ -769,13 +770,14 @@ impl Opt {
             rotation_x: !self.ignore_ik_rotation_x,
             rotation_y: !self.ignore_ik_rotation_y,
             rotation_z: !self.ignore_ik_rotation_z,
+            ..Default::default()
         }
     }
 
     #[cfg(target_arch = "wasm32")]
     pub fn from_params() -> Result<Self, crate::Error> {
         let href = crate::utils::window()?.location().href()?;
-        log::debug!("href={}", href);
+        debug!("href={}", href);
         let url = url::Url::parse(&href).map_err(|e| e.to_string())?;
         Ok(serde_qs::from_str(url.query().unwrap_or_default()).map_err(|e| e.to_string())?)
     }
